==> dfisher_2022a-0.1.11.tar.gz: dfisher_2022a-0.1.11/python/dfisher_2022a/app.py <==
import logging

from lmfit import Model
from mpdaf.obj import Cube

from .fits import CubeFitterLM, ResultLM
from . import CubeRegion, Line, ProcessedCube, ReadCubeFile, RestCube, SNRMap


class FitInterface():
    def __init__(self, cubefile, varfile=None):
        self.cubefile = cubefile
        self.varfile = varfile
        self.rawcube = ReadCubeFile(cubefile, varfile).cube
        self.out = ResultLM()

    def prepare_data(self, line: str, z=0., left=15, right=15, snr_threshold=None):
        p = ProcessedCube(self.cube, z=z, snr_threshold=snr_threshold)
        p.de_redshift(z=z)
        p.select_region(line=line, left=15, right=15)
        p.get_snrmap(snr_threshold=snr_threshold)
        self.p = p
        self.out.get_output(p)

def prepare_data(cube: Cube, line: str, z=0., left=15, right=15, snr_threshold=None):
    p = ProcessedCube(cube=cube, z=z, snr_threshold=snr_threshold)
    p.de_redshift(z=z)
    p.select_region(line=line, left=15, right=15)
    p.get_snrmap(snr_threshold=snr_threshold)
    return p

def fit_lm(cubefile, line: str, model: Model, varfile=None, z=0.,
            left=15, right=15, snr_threshold=None, fit_method="leastsq"):
    out = ResultLM()
    setattr(out,"CubeFile", cubefile)
    setattr(out, "VarFile", varfile)
    rawcube = ReadCubeFile(cubefile, varfile).cube
    
    print("prepare data")
    p = prepare_data(rawcube, line, z, left, right, snr_threshold)
    out.get_output(p)

    print("start fitting data")
    fr = CubeFitterLM(p.data, p.weight, p.x, model, fit_method=fit_method)
    fr.fit_cube()
    out.get_output(fr)
    out.save()
    return out

==> dfisher_2022a-0.1.22.tar.gz: dfisher_2022a-0.1.22/python/dfisher_2022a/app.py <==
import logging
import os

from lmfit import Model
from mpdaf.obj import Cube

from .cube import CubeRegion, ProcessedCube, ReadCubeFile, RestCube, SNRMap
from .fits.cpufitter import CubeFitterLM, ResultLM
from .line import Line

logger = logging.getLogger(__name__)

# CPU COUNT
CPU_COUNT = os.cpu_count()
class FitInterface():
    def __init__(self, cubefile, varfile=None):
        self.cubefile = cubefile
        self.varfile = varfile
        self.rawcube = ReadCubeFile(cubefile, varfile).cube
        self.out = ResultLM()

    def prepare_data(self, line: str, z=0., left=15, right=15, snr_threshold=None):
        p = ProcessedCube(self.cube, z=z, snr_threshold=snr_threshold)
        p.de_redshift(z=z)
        p.select_region(line=line, left=15, right=15)
        p.get_snrmap(snr_threshold=snr_threshold)
        self.p = p
        self.out.get_output(p)

def prepare_data(cube: Cube, line: str, z=0., left=15, right=15, snr_threshold=None):
    """"Get data ready for fitting."""
    p = ProcessedCube(cube=cube, z=z, snr_threshold=snr_threshold)
    p.de_redshift(z=z)
    p.select_region(line=line, left=left, right=right)
    p.get_snrmap(snr_threshold=snr_threshold)
    return p

def fit_lm(cubefile, line: str, model: Model, varfile=None, z=0.,
            left=15, right=15, snr_threshold=None, nprocess=CPU_COUNT, fit_method="leastsq", mode="parallel", **kwargs):
    out = ResultLM()
    setattr(out,"CubeFile", cubefile)
    setattr(out, "VarFile", varfile)
    logger.info("Read in cube")
    rawcube = ReadCubeFile(cubefile, varfile).cube
    
    logger.info("Prepare data")
    p = prepare_data(rawcube, line, z, left, right, snr_threshold)
    out.get_output(p)

    logger.info("Start fitting data")
    fr = CubeFitterLM(p.data, p.weight, p.x, model, nprocess=nprocess, method=fit_method, **kwargs)
    if mode == "parallel":
        fr.fit_cube()
    if mode == "serial":
        fr.fit_serial()
    
    out.get_output(fr)
    out.save()
    return out
